@@ -6,3 +6,7 @@
 #'
 #' @export
 trim_anything <- strex::str_trim_anything
+
+#' @rdname trim_anything
+#' @export
+str_trim_anything <- trim_anything
